==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/msready/search/by-mass-3083de-POST.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/msready/search/by-mass/", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Wed, 22 May 2024 19:50:04 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", vary = "Origin", 
        vary = "Access-Control-Request-Method", vary = "Access-Control-Request-Headers", 
        `x-content-type-options` = "nosniff", `x-vcap-request-id` = "93e85daa-030c-4fa9-4c42-fbdb747a3e2c", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "mDjjwyYEBvMdCSWFA_97Kzw6m5IW2DUzMUk5oSv8xL9_ucydut2TAw=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Wed, 22 May 2024 19:50:04 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            vary = "Origin", vary = "Access-Control-Request-Method", 
            vary = "Access-Control-Request-Headers", `x-content-type-options` = "nosniff", 
            `x-vcap-request-id` = "93e85daa-030c-4fa9-4c42-fbdb747a3e2c", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "mDjjwyYEBvMdCSWFA_97Kzw6m5IW2DUzMUk5oSv8xL9_ucydut2TAw=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x46, 0x61, 0x69, 0x6c, 0x65, 0x64, 0x20, 0x74, 0x6f, 0x20, 
    0x72, 0x65, 0x61, 0x64, 0x20, 0x72, 0x65, 0x71, 0x75, 0x65, 
    0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x6d, 0x73, 0x72, 0x65, 0x61, 0x64, 0x79, 0x2f, 0x73, 
    0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 0x6d, 
    0x61, 0x73, 0x73, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1716407404, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.2e-05, 
    connect = 0, pretransfer = 0.000176, starttransfer = 0.254375, 
    total = 0.254418)), class = "response")

==> ctxR_1.1.2.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/msready/search/by-mass-3083de-POST.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/msready/search/by-mass/", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:34:34 GMT", `x-xss-protection` = "1; mode=block", 
        `x-frame-options` = "DENY", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", vary = "Origin", 
        vary = "Access-Control-Request-Method", vary = "Access-Control-Request-Headers", 
        `x-content-type-options` = "nosniff", `x-vcap-request-id` = "87ec5d5d-5c99-4256-4b5f-848ce9189224", 
        `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "2__gJTozN8K5vWn5UkVo5hzwEy8f5J0MzMmysFuc8StR5OCwC-nFCA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:34:34 GMT", `x-xss-protection` = "1; mode=block", 
            `x-frame-options` = "DENY", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            vary = "Origin", vary = "Access-Control-Request-Method", 
            vary = "Access-Control-Request-Headers", `x-content-type-options` = "nosniff", 
            `x-vcap-request-id` = "87ec5d5d-5c99-4256-4b5f-848ce9189224", 
            `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "2__gJTozN8K5vWn5UkVo5hzwEy8f5J0MzMmysFuc8StR5OCwC-nFCA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x46, 0x61, 0x69, 0x6c, 0x65, 0x64, 0x20, 0x74, 0x6f, 0x20, 
    0x72, 0x65, 0x61, 0x64, 0x20, 0x72, 0x65, 0x71, 0x75, 0x65, 
    0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x6d, 0x73, 0x72, 0x65, 0x61, 0x64, 0x79, 0x2f, 0x73, 
    0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 0x6d, 
    0x61, 0x73, 0x73, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1731080074, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.9e-05, 
    connect = 0, pretransfer = 0.000137, starttransfer = 0.284748, 
    total = 0.284803)), class = "response")
